@@ -5,7 +5,7 @@
 #    |_|_|_|_|_||_|_\__,_|_.__/
 #    simple python object store
 #
-# Copyright 2009-2010, 2014-2015 Thomas Perl <thp.io>. All rights reserved.
+# Copyright 2009-2010, 2014-2017 Thomas Perl <thp.io>. All rights reserved.
 #
 # Permission to use, copy, modify, and/or distribute this software for any
 # purpose with or without fee is hereby granted, provided that the above
@@ -23,7 +23,7 @@
 """A simple SQLite3-based store for Python objects"""
 
 __author__ = 'Thomas Perl <m@thp.io>'
-__version__ = '2.0.1'
+__version__ = '2.0.2'
 __url__ = 'http://thp.io/2010/minidb/'
 __license__ = 'ISC'
 
@@ -167,6 +167,7 @@ class Store(object):
 
     def close(self):
         with self.lock:
+            self.db.isolation_level = None
             self._execute('VACUUM')
             self.db.close()
 
@@ -569,6 +570,7 @@ class func(object):
     max = staticmethod(lambda *args: Function('max', *args))
     min = staticmethod(lambda *args: Function('min', *args))
     sum = staticmethod(lambda *args: Function('sum', *args))
+    distinct = staticmethod(lambda *args: Function('distinct', *args))
     random = staticmethod(lambda: Function('random'))
 
     abs = staticmethod(lambda a: Function('abs', a))
@@ -605,6 +607,7 @@ class OperatorMixin(object):
     max = property(lambda a: Function('max', a))
     min = property(lambda a: Function('min', a))
     sum = property(lambda a: Function('sum', a))
+    distinct = property(lambda a: Function('distinct', a))
 
     asc = property(lambda a: Operation(a, 'ASC'))
     desc = property(lambda a: Operation(a, 'DESC'))
